@@ -1,13 +1,13 @@
 
-/* $Id: stdata.h,v 201.0 2002/02/14 09:29:14 sgifford Exp $ */
+/* $Id: stdata.h,v 400.1 2002/07/25 08:43:16 sgifford Exp $ */
 
 #ifndef STDATA_H
 #define STDATA_H
 
+int startalk_set_version(char *v);
+int startalk_initialize_stdata(int serialfd);
+void startalk_dump_phonebook_offsets(void);
 struct startalk_phonebook_entry *startalk_get_phonebook_entry(int serialfd, int num);
-int startalk_get_greeting(int serialfd, char *greeting, int bufsiz);
-int startalk_run_cmd(int serialfd, char *msgbuf, int size);
-int startalk_dump_cmd(int serialfd, char *msgbuf, int size);
 int startalk_put_phonebook_entry(int serialfd, int num, struct startalk_phonebook_entry *pbe);
 int startalk_remove_phonebook_entry(int serialfd, int num);
 
